package com.google.code.fastbuilder.internal.spec;

import com.google.code.fastbuilder.internal.*;

/**
 * Setters with same name as attributes.
 * Getters starting with "get".
 * 
 * Example:
 * 
 * <pre>
 * {@code
 *   private int value;
 *   Builder value(int val) {
 *     ...
 *   }
 *   int getValue() {
 *     ...
 *   }
 * }
 * </pre>
 */
public class SimpleSetterBuilderSpecification implements BuilderSpecification {

	public static final SimpleSetterBuilderSpecification INSTANCE = new SimpleSetterBuilderSpecification();

	private static final String GET_PREFIX = "get";
	private static final String IS_PREFIX = "is";

	public boolean isReader(String name, int argCount) {
		return argCount == 0 && (name.startsWith(GET_PREFIX) || name.startsWith(IS_PREFIX));
	}

	public boolean isWriter(String name, int argCount) {
		return argCount == 1;
	}

	@Override
	public String getFieldNameFromReader(String name) {
		String aux;
		if (name.startsWith(GET_PREFIX)) {
			aux = name.substring(GET_PREFIX.length());
		} else {
			aux = name.substring(IS_PREFIX.length());
		}
		if (aux.length() > 0) {
			aux = Character.toLowerCase(aux.charAt(0)) + aux.substring(1);
		}
		return aux;
	}
}
